@@ -13,6 +13,8 @@ from tornado.log import LogFormatter as TornadoLogFormatter  # 避免命名歧
 from tornado.options import options, define
 from typing import Optional
 
+from tornado_sqlalchemy import SQLAlchemy
+
 from lesscode.db.init_connection_pool import InitConnectionPool
 from lesscode.web.router_mapping import RouterMapping
 
@@ -37,6 +39,7 @@ define("eureka_instance_port", default=8901, type=int, help="eureka实例ip或
 define("rms_register_enable", default=False, type=bool, help="是否启动资源注册")
 define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
 define("running_env", default="local", type=str, help="运行环境")
+define("db", default=None, type=SQLAlchemy, help="SqlAlchemy")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -122,7 +125,7 @@ class WebServer:
             RouterMapping.instance(),
             cookie_secret=options.cookie_secret,
             static_path=options.static_path,
-            db = options.db,
+            db=options.db,
             debug=True if options.logging == "DEBUG" else False  # 依据日志记录级别确认是否开启调试模式
         )
         self.server = tornado.httpserver.HTTPServer(self.app, max_buffer_size=500 * 1024 * 1024, xheaders=True)  # 500M
